-- ver 0.02

-- Specify the default context to assign to your imported email
property pstrContext : "Mail"

on run
	-- READ THE SELECTED ITEMS OF MAIL AND CREATE OF TASKS
	set {lngMail, strReport} to MakeMailTasks(GetMailSeln())
	
	-- AND REPORT THRU GROWL
	if strReport ≠ "" then Growlify("Create OF Tasks from Mail", "OF Tasks created from Mail", ¬
		(lngMail as string) & " tasks created in OmniFocus:" & return & strReport)
end run

on GetMailSeln()
	tell application "Mail"
		set lstSeln to selection
		set lngSeln to length of lstSeln
		if lngSeln < 1 then return {}
		
		repeat with i from 1 to lngSeln
			tell item i of lstSeln
				set strSubject to subject
				set strURL to "[url=message:%3C" & (my encode(message id)) & "%3E]" & strSubject & " (From " & sender & ")" & "[/url]"
				set strBody to "Link to Message: " & strURL & return & return & content
			end tell
			set item i of lstSeln to {strSubject, strBody}
		end repeat
	end tell
	return lstSeln
end GetMailSeln

on MakeMailTasks(lstSubjectBody)
	set lngMail to length of lstSubjectBody
	if lngMail < 1 then return {0, ""}
	
	-- ENSURE THAT THE SPECIFIED CONTEXT EXISTS
	set oContext to GetContext(pstrContext)
	if oContext is not missing value then
		set strContext to " @" & pstrContext
	else
		set strContext to ""
	end if
	
	-- CREATE THE SET OF TASKS
	set strReport to ""
	tell application id "OFOC"
		tell default document
			repeat with oMsg in lstSubjectBody
				set {strSubject, strBody} to oMsg
				parse tasks with transport text strSubject & strContext & " //" & strBody
				set strReport to strReport & return & "• " & strSubject
			end repeat
		end tell
	end tell
	return {lngMail, strReport}
end MakeMailTasks

on GetContext(strName)
	if strName ≠ "" then
		tell application "OmniFocus"
			tell default document
				set lstMatches to flattened contexts where name = strName
				if length of lstMatches > 0 then
					return first item of lstMatches
				else
					return (make new context with properties {name:strName})
				end if
			end tell
		end tell
	else
		return missing value
	end if
end GetContext

on encode(strPath)
	do shell script "python -c 'import sys, urllib as ul; print ul.quote(sys.argv[1])' " & ¬
		quoted form of strPath
end encode

on Growlify(strApp, strNote, strMsg)
	tell application id "sevs"
		if (count of (processes where bundle identifier is "com.Growl.GrowlHelperApp")) > 0 then
			tell application id "com.Growl.GrowlHelperApp"
				register as application strApp all notifications {strNote} ¬
					default notifications {strNote} ¬
					icon of application "OmniFocus"
				
				notify with name strNote title strNote ¬
					description strMsg application name strApp
			end tell
		end if
	end tell
end Growlify
